pub struct RelayerApiKey { /* private fields */ }Expand description
Relayer API key used to authorize gasless Deposit Wallet submissions.
Implementations
Sourceimpl RelayerApiKey
impl RelayerApiKey
Sourcepub fn new(key: SecretString, address: &str) -> Result<Self>
pub fn new(key: SecretString, address: &str) -> Result<Self>
Creates a Relayer API key from the key value and signer address.
Errors
Returns an error if the key is empty or address is not a valid EVM address.
pub fn key(&self) -> &str
pub fn address(&self) -> &str